.. :changelog:

Release History
---------------

1.3.1 (2015-08-09)
++++++++++++++++++

* Added nm_check_uptime

1.3.0 (2015-07-29)
++++++++++++++++++

* Added nm_check_uptime
* Added nm_check_version (only reports in this version)

1.2 (2015-07-26)
++++++++++++++++

* Added nm_check_admin_up_oper_down
* Added nm_check_asa_connections
* Cleaned up code

1.1 (2015-07-25)
++++++++++++++++

* First release to pypi
